/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "MediaList.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomMediaList.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomMediaList.h"
#include "gdom/PrivateIntGdomMediaList.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::MediaList* obj)
{
    return WebCore::cacheDOMObject<WebCore::MediaList, GDOMMediaList>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMMediaList::GDOMMediaList(PassRefPtr<WebCore::MediaList> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMMediaList::~GDOMMediaList()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

gchar *
gdom_media_list_item (GdomMediaList *thiz, gulong index)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::MediaList * item = (gdom_media_list_get_private(thiz));
    g_return_val_if_fail (item, 0);
    gchar * res = _G_GET_UTF8(item->item(index));
    return res;

}

void
gdom_media_list_delete_medium (GdomMediaList *thiz, gchar * old_medium)
{
    g_return_if_fail (thiz);
    WebCore::MediaList * item = (gdom_media_list_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (old_medium);
    WebCore::String _g_old_medium = WebCore::String::fromUTF8(old_medium);
    WebCore::ExceptionCode ec = 0;
    item->deleteMedium(_g_old_medium, ec);

}

void
gdom_media_list_append_medium (GdomMediaList *thiz, gchar * new_medium)
{
    g_return_if_fail (thiz);
    WebCore::MediaList * item = (gdom_media_list_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (new_medium);
    WebCore::String _g_new_medium = WebCore::String::fromUTF8(new_medium);
    WebCore::ExceptionCode ec = 0;
    item->appendMedium(_g_new_medium, ec);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "MediaList.h"
#include <gdom/GdomMediaList.h>
#include <gdom/PrivateGdomMediaList.h>
#include <gdom/PrivateIntGdomMediaList.h>
#include <gdom/GdomMediaListprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomMediaList, gdom_media_list, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomMediaListPrivate {
    class WebCore::MediaList *item;
};

#define GDOM_MEDIA_LIST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_MEDIA_LIST, GdomMediaListPrivate))
*/
G_END_DECLS
WebCore::MediaList *
gdom_media_list_get_private(GdomMediaList *request)
{
    GDOMMediaList *res;
    res = static_cast<GDOMMediaList*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::MediaList*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_MEDIA_TEXT,
    PROP_LENGTH,
};


static void gdom_media_list_finalize(GObject* object)
{
    /*GdomMediaList* request = GDOM_MEDIA_LIST(object);*/
    /*GdomMediaListPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_media_list_parent_class)->finalize(object);
}

static void gdom_media_list__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomMediaList *self = GDOM_MEDIA_LIST(object);
    WebCore::MediaList * gself = (gdom_media_list_get_private(self));
    switch (prop_id) {
     case PROP_MEDIA_TEXT:
    {
         WebCore::ExceptionCode ec = 0;
         gself->setMediaText(WebCore::String::fromUTF8(g_value_get_string (value)) , ec );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_media_list__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomMediaList *self = GDOM_MEDIA_LIST(object);
    WebCore::MediaList * gself = (gdom_media_list_get_private(self));
    switch (prop_id) {
    case PROP_MEDIA_TEXT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->mediaText()));
         break;
    }
    case PROP_LENGTH:
    {
         g_value_set_ulong (value, gself->length());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_media_list_class_init(GdomMediaListClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_media_list_finalize;
    g_klass->set_property = gdom_media_list__set_property_fn;
    g_klass->get_property = gdom_media_list__get_property_fn;

    g_object_class_install_property (g_klass, PROP_MEDIA_TEXT,
            g_param_spec_string ("media_text", /* name */
                "media_list_media_text", /* short description */
                "read-write  gchar * MediaList.media_text", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_LENGTH,
            g_param_spec_ulong ("length", /* name */
                "media_list_length", /* short description */
                "read-only  gulong MediaList.length", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomMediaListPrivate));*/
}

static void gdom_media_list_init(GdomMediaList* request)
{
    /*GdomMediaListPrivate* priv = GDOM_MEDIA_LIST_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

